<?php

namespace App\Http\Controllers;

use App\Models;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class RoleController extends Controller
{
    public function CreateRole(Request $request)
    {
        $validator = Validator::make($request->all(), [
            "name" => "required|between:1,64",
            "description" => "max:255",
        ]);
        if ($validator->fails()) {
            return $this->fail(REQUEST_PARAM_ERROR, $this->error[REQUEST_PARAM_ERROR], $validator->errors());
        }

        $params = [];
        $params["name"] = $request->input("name");
        $params["description"] = $request->input("description");

        $role = new Models\Role();
        $result = $role->CreateRole($params);
        if ($result["code"] == 0) {
            return $this->success($result["data"]);
        }
        return $this->fail($result["code"], $this->error[$result["code"]]);;
    }

    public function ModifyRole(Request $request)
    {
        $validator = Validator::make($request->all(), [
            "id" => "required|integer|min:1",
            "name" => "between:1,64",
            "description" => "max:255",
        ]);
        if ($validator->fails()) {
            return $this->fail(REQUEST_PARAM_ERROR, $this->error[REQUEST_PARAM_ERROR], $validator->errors());
        }

        $params = [];
        $params["id"] = $request->input("id");
        $params["name"] = $request->input("name");
        $params["description"] = $request->input("description");

        $role = new Models\Role();
        $code = $role->ModifyRole($params);
        if ($code == 0) {
            return $this->success("success");
        }
        return $this->fail($code, $this->error[$code]);
    }

    public function DeleteRole(Request $request)
    {
        $validator = Validator::make($request->all(), [
            "id" => "required|integer|min:1",
        ]);
        if ($validator->fails()) {
            return $this->fail(REQUEST_PARAM_ERROR, $this->error[REQUEST_PARAM_ERROR], $validator->errors());
        }

        $params = [];
        $params["id"] = $request->input("id");

        $role = new Models\Role();
        $code = $role->DeleteRole($params);
        if ($code == 0) {
            return $this->success("success");
        }
        return $this->fail($code, $this->error[$code]);
    }

    public function ListRole(Request $request)
    {
        $validator = Validator::make($request->all(), [
            "page" => "integer|min:1",
            "pageCount" => "integer|min:1"
        ]);
        if ($validator->fails()) {
            return $this->fail(REQUEST_PARAM_ERROR, $this->error[REQUEST_PARAM_ERROR], $validator->errors());
        }

        $params = [];
        $params["page"] = (int)$request->input("page");
        $params["pageCount"] = (int)$request->input("pageCount");

        $role = new Models\Role();
        $result = $role->ListRole($params);
        return $result;
    }
}
